FingerprintEventResponse class

Class which represents fingerprint event object.

Constructors

FingerprintEventResponse(String apiCiphertextSignature, String publicEncryptionKey, String ciphertext, String iv, String salt)

Properties

apiCiphertextSignature String
final
ciphertext String
final
hashCode int
The hash code for this object.
no setterinherited
iv String
final
publicEncryptionKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salt String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) FingerprintEventResponse
Conversion helper method.